@@ -26,8 +26,10 @@ extensions = [
     "sphinx.ext.napoleon",
     "autodocsumm",
     "myst_parser",
+    "sphinxemoji.sphinxemoji",
 ]
 autodoc_default_options = {"autosummary": True}
+sphinxemoji_style = "twemoji"
 
 templates_path = ["_templates"]
 exclude_patterns = []
@@ -37,7 +39,7 @@ language = "Python"
 # -- Options for HTML output -------------------------------------------------
 # https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output
 
-html_theme = "pyramid"
+html_theme = "karma_sphinx_theme"
 html_static_path = ["_static"]
 html_favicon = "_static/favicon.ico"
 html_logo = "_static/favicon.ico"
